@@ -2,16 +2,6 @@
 from PyObjCTools.TestSupport import *
 from SearchKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-try:
-    long
-except NameError:
-    long = int
-
 class TestSKDocument (TestCase):
     def testTypes(self):
         self.assertIsCFType(SKDocumentRef)
